| Title: | Random Sampling Distribution C++ Routines for Armadillo |
|---|---|
| Description: | Provides popular sampling distributions C++ routines based in armadillo through a header file approach. |
| Authors: | James Joseph Balamuta [aut, cre, cph] (ORCID: <https://orcid.org/0000-0003-2826-8458>), Steven Andrew Culpepper [ctb] (ORCID: <https://orcid.org/0000-0003-4226-6176>) |
| Maintainer: | James Joseph Balamuta <[email protected]> |
| License: | GPL (>=2) |
| Version: | 0.0.1 |
| Built: | 2026-05-25 08:55:42 UTC |
| Source: | https://github.com/coatless-rpkg/rgen |
Provides popular sampling distributions C++ routines based in armadillo through a header file approach.
Maintainer: James Joseph Balamuta [email protected] (ORCID) [copyright holder]
Other contributors:
Steven Andrew Culpepper [email protected] (ORCID) [contributor]
Useful links:
Report bugs at https://github.com/coatless-rpkg/rgen/issues