Welcome to ClientVPS Mirrors

Help for package rgen
Title: Random Sampling Distribution C++ Routines for Armadillo
Version: 0.0.1
Description: Provides popular sampling distributions C++ routines based in armadillo through a header file approach.
Depends: R (≥ 3.3.0)
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2017-10-28 18:00:42 UTC; jjb
Author: James Balamuta [aut, cre], Steven Culpepper [ctb]
Maintainer: James Balamuta <balamut2@illinois.edu>
Repository: CRAN
Date/Publication: 2017-10-29 16:47:08 UTC

This package provides header-only sampling routines.

Description

This package provides header-only sampling routines.

Author(s)

Maintainer: James Balamuta balamut2@illinois.edu

Other contributors:

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.